Package: smfsb
Type: Package
Title: Stochastic Modelling for Systems Biology
Version: 1.5
Date: 2024-01-11
Author: Darren Wilkinson
Maintainer: Darren Wilkinson <darrenjwilkinson@btinternet.com>
Description: Code and data for modelling and simulation of stochastic kinetic biochemical network models. It contains the code and data associated with the second and third editions of the book Stochastic Modelling for Systems Biology, published by Chapman & Hall/CRC Press.
License: LGPL-3
Depends: R (>= 2.9.0), abind (>= 1.3), parallel (>= 3.2.0)
Suggests: deSolve (>= 1.9)
NeedsCompilation: yes
Packaged: 2024-01-12 09:01:21 UTC; darren
Repository: CRAN
Date/Publication: 2024-01-13 13:00:04 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 22:25:48 UTC; unix
Archs: smfsb.so.dSYM
